@@ -256,7 +256,7 @@ precompile_regexes (const TerminalRegexPattern *regex_patterns,
 
 #ifdef WITH_PCRE2
       (*regexes)[i] = vte_regex_new (regex_patterns[i].pattern, -1,
-                                     PCRE2_UTF | PCRE2_NO_UTF_CHECK |
+                                     PCRE2_UTF | PCRE2_NO_UTF_CHECK | PCRE2_MULTILINE |
                                      (regex_patterns[i].caseless ? PCRE2_CASELESS : 0),
                                      &error);
       g_assert_no_error (error);
@@ -269,6 +269,7 @@ precompile_regexes (const TerminalRegexPattern *regex_patterns,
 #else
       (*regexes)[i] = g_regex_new (regex_patterns[i].pattern,
                                    G_REGEX_OPTIMIZE |
+                                   G_REGEX_MULTILINE |
                                    (regex_patterns[i].caseless ? G_REGEX_CASELESS : 0),
                                    0, &error);
       g_assert_no_error (error);
@@ -1937,6 +1938,7 @@ terminal_screen_check_extra (TerminalScreen *screen,
   gboolean flavor_number_found = FALSE;
 
   matches = g_newa (char *, n_extra_regexes);
+  memset(matches, 0, sizeof(char*) * n_extra_regexes);
 
   if (
 #ifdef WITH_PCRE2
@@ -1972,8 +1974,6 @@ terminal_screen_check_extra (TerminalScreen *screen,
             }
         }
     }
-
-  return NULL;
 }
 
 /**
